@@ -96,6 +96,15 @@ class CommandBit(FormulaCommand):
     self.add(parameter)
     return parameter
 
+  def parsesquare(self, pos):
+    "Parse a square bracket"
+    bracket = SquareBracket()
+    if not bracket.detect(pos):
+      return None
+    bracket.parsebit(pos)
+    self.add(bracket)
+    return bracket
+
 class EmptyCommand(CommandBit):
   "An empty command (without parameters)"
 
@@ -141,27 +150,31 @@ class SymbolFunction(CommandBit):
     self.output = TaggedOutput().settag(self.translated)
     self.parseparameter(pos)
 
-class LiteralFunction(CommandBit):
-  "A function where parameters are read literally"
+class TextFunction(CommandBit):
+  "A function where parameters are read as text."
 
-  commandmap = FormulaConfig.literalfunctions
+  commandmap = FormulaConfig.textfunctions
 
   def parsebit(self, pos):
-    "Parse a literal parameter"
+    "Parse a text parameter"
     self.output = TaggedOutput().settag(self.translated)
-    bracket = Bracket().parseliteral(pos)
+    bracket = Bracket().parsetext(pos)
     self.add(bracket)
-    self.contents.append(FormulaConstant(bracket.literal))
 
   def process(self):
     "Set the type to font"
     self.type = 'font'
 
-class LabelFunction(LiteralFunction):
+class LabelFunction(CommandBit):
   "A function that acts as a label"
 
   commandmap = FormulaConfig.labelfunctions
 
+  def parsebit(self, pos):
+    "Parse a literal parameter"
+    bracket = Bracket().parseliteral(pos)
+    self.add(bracket)
+
   def process(self):
     "Do not process the inside"
     self.type = 'font'
@@ -204,24 +217,15 @@ class HybridFunction(CommandBit):
     "Parse a function with [] and {} parameters"
     square = self.parsesquare(pos)
     bracket = self.parseparameter(pos)
-    bracket.output = TaggedOutput().settag(self.translated[1])
-    if self.translated[0] == 'sqrt':
+    bracket.output = TaggedOutput().settag(self.translated)
+    if self.command == '\sqrt':
       self.sqrt(square, bracket)
-    elif self.translated[0] == 'unit':
+    elif self.command == '\unit':
       self.unit(square, bracket)
     else:
-      Trace.error('Unknown hybrid function ' + self.translated[0])
+      Trace.error('Unknown hybrid function ' + self.command)
       return
 
-  def parsesquare(self, pos):
-    "Parse a square bracket"
-    bracket = SquareBracket()
-    if not bracket.detect(pos):
-      return
-    bracket.parsebit(pos)
-    self.add(bracket)
-    return bracket
-
   def sqrt(self, root, radical):
     "A square root -- process the root"
     if root:
@@ -243,20 +247,32 @@ class FractionFunction(CommandBit):
     "Parse a fraction function with two parameters"
     tags = self.translated
     self.output = TaggedOutput().settag(self.translated[0])
+    align = self.parsesquare(pos)
     parameter1 = self.parseparameter(pos)
     if not parameter1:
+      Trace.error('Invalid fraction function ' + self.translated[0] + 
+          ': missing first {}')
       return
-    parameter1.output = TaggedOutput().settag(self.translated[1])
+    numerator = self.translated[1]
+    if align and self.command == '\\cfrac':
+      self.contents.pop(0)
+      numerator = numerator[:-1] + '-' + align.contents[0].original + '"'
+    parameter1.output = TaggedOutput().settag(numerator)
     self.contents.append(FormulaConstant(self.translated[2]))
     parameter2 = self.parseparameter(pos)
     if not parameter2:
+      Trace.error('Invalid fraction function ' + self.translated[0] + 
+          ': missing second {}')
       return
     parameter2.output = TaggedOutput().settag(self.translated[3])
+    if align and self.command == '\\unitfrac':
+      parameter1.type = 'font'
+      parameter2.type = 'font'
 
 FormulaFactory.bits += [FormulaCommand(), SymbolFunction()]
 FormulaCommand.commandbits = [
     EmptyCommand(), AlphaCommand(), OneParamFunction(), DecoratingFunction(),
-    FractionFunction(), FontFunction(), LabelFunction(), LiteralFunction(),
+    FractionFunction(), FontFunction(), LabelFunction(), TextFunction(),
     HybridFunction(),
     ]
 
