@@ -131,6 +131,8 @@ class WholeFormula(FormulaBit):
     "Process the whole formula"
     for index, bit in enumerate(self.contents):
       bit.process()
+      # no units processing
+      continue
       if bit.type == 'alpha':
         # make variable
         self.contents[index] = TaggedBit().complete([bit], 'i')
