@@ -23,6 +23,7 @@
 # eLyXer runtime options
 
 import codecs
+import os.path
 from util.trace import *
 from util.clparse import *
 
@@ -50,10 +51,17 @@ class Options(object):
   forceformat = None
   lyxformat = False
   target = None
+  cutpart = 1
+
   branches = dict()
 
+  def __init__(self):
+    self.invokedas = None
+
   def parseoptions(self, args):
     "Parse command line options"
+    self.invokedas = os.path.basename(args[0])
+    del args[0]
     parser = CommandLineParser(Options)
     result = parser.parseoptions(args)
     if result:
@@ -76,22 +84,29 @@ class Options(object):
 
   def usage(self):
     "Show correct usage"
-    Trace.error('Usage: elyxer.py [filein] [fileout].')
-    Trace.error('  Options:')
-    Trace.error('    --nocopy: disables the copyright notice at the bottom')
-    Trace.error('    --quiet: disables all runtime messages')
-    Trace.error('    --debug: enable debugging messages (for developers)')
-    Trace.error('    --title "title": set the generated page title')
-    Trace.error('    --directory "images_dir": look for images in the specified directory')
+    Trace.error('Usage: ' + self.invokedas + ' [options] [filein] [fileout]')
+    Trace.error('Convert LyX input file "filein" to HTML file "fileout".')
+    Trace.error('If filein (or fileout) is not given use standard input (or output).')
+    self.showoptions()
+
+  def showoptions(self):
+    "Show all possible options"
+    Trace.error('  Valid options:')
+    Trace.error('    --nocopy:                   disables the copyright notice at the bottom')
+    Trace.error('    --quiet:                    disables all runtime messages')
+    Trace.error('    --debug:                    enable debugging messages (for developers)')
+    Trace.error('    --title "title":            set the generated page title')
+    Trace.error('    --directory "images_dir":   look for images in the specified directory')
     Trace.error('    --destdirectory "dest_dir": put converted images into this directory')
-    Trace.error('    --css "file.css": use a custom CSS file')
-    Trace.error('    --version: show version number and release date')
-    Trace.error('    --html: output HTML 4.0 instead of the default XHTML')
-    Trace.error('    --unicode: full Unicode output')
+    Trace.error('    --css "file.css":           use a custom CSS file')
+    Trace.error('    --version:                  show version number and release date')
+    Trace.error('    --html:                     output HTML 4.0 instead of the default XHTML')
+    Trace.error('    --unicode:                  full Unicode output')
     Trace.error('    --forceformat ".extension": force image output format')
-    Trace.error('    --lyxformat: return the highest LyX version that can be converted')
-    Trace.error('    --toc "original.html": create a TOC with links to the original')
-    Trace.error('    --target "frame": make all links point to the given frame')
+    Trace.error('    --lyxformat:                return the highest LyX version that can be')
+    Trace.error('                                converted')
+    Trace.error('    --toc "original.html":      create a TOC with links to the original')
+    Trace.error('    --target "frame":           make all links point to the given frame')
     exit()
 
   def showversion(self):
